import os

from flask import Flask
from flask_cors import CORS
from flask_sqlalchemy import SQLAlchemy


from api.settings import app_settings

# instantiate the extensions
db = SQLAlchemy()
cors = CORS()


def create_app(script_info=None):

    app = Flask(__name__)

    # set config
    config_engine = app_settings[os.getenv("APP_SETTINGS", "dev")]()
    app.config.from_object(config_engine)

    # set up extensions
    db.init_app(app)
    cors.init_app(app)

    #     migrate.init_app(app, db)

    # register blueprints
    from .app import main_blueprint

    app.register_blueprint(main_blueprint)
    #     from project.api.users import users_blueprint
    #     app.register_blueprint(users_blueprint)

    # shell context for flask cli
    app.shell_context_processor({"app": app, "db": db})
    return app
