import os


# TODO Add  postgres params option
def build_postgres_uri(host, user, dbname, passwd=None, port="5432", sslmode=None):
    """Builds a PostgreSQL uri.

    See https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING for additional details.
    """

    if passwd:
        uri = f"postgresql://{user}:{passwd}@{host}:{port}/{dbname}"
    else:
        uri = f"postgresql://{user}@{host}:{port}/{dbname}"
    if sslmode:
        uri = f"{uri}?sslmode={sslmode}"
    return uri


class BaseConfigEngine:
    """Base configuration engine"""

    POSTGRES_HOST = os.getenv("POSTGRES_HOST", default="localhost")
    POSTGRES_USER = os.getenv("POSTGRES_USER", default="postgres")
    POSTGRES_APP_DATABASE = os.getenv("POSTGRES_APP_DATABASE", default="postgres")
    POSTGRES_PASSWORD = os.getenv("POSTGRES_PASSWORD")
    POSTGRES_PORT = os.getenv("POSTGRES_PORT", default="5432")
    POSTGRES_SSL_MODE = os.getenv("POSTGRES_SSL_MODE", default="prefer")
    POSTGRES_PARAMS = os.getenv("POSTGRES_PARAMS")
    SECRET_KEY = os.getenv("SECRET_KEY", "defaultsecretkey")
    SQLALCHEMY_TRACK_MODIFICATIONS = False

    @property
    def SQLALCHEMY_DATABASE_URI(self):  # Note: all caps
        return build_postgres_uri(
            self.POSTGRES_HOST,
            self.POSTGRES_USER,
            self.POSTGRES_APP_DATABASE,
            self.POSTGRES_PASSWORD,
            self.POSTGRES_PORT,
            self.POSTGRES_SSL_MODE,
        )


class DevConfigEngine(BaseConfigEngine):
    DEBUG = True


class TestingConfigEngine(BaseConfigEngine):
    TESTING = True


class ProductionConfigEngine(BaseConfigEngine):
    DEBUG = False


app_settings = {
    "dev": DevConfigEngine,
    "development": DevConfigEngine,
    "test": TestingConfigEngine,
    "testing": TestingConfigEngine,
    "prod": ProductionConfigEngine,
    "production": ProductionConfigEngine,
}
